==================================
Ironic Python Agent Administration
==================================

Overview
========

Ironic Python Agent is an agent for controlling and deploying Ironic controlled
baremetal nodes. Typically run in a ramdisk, the agent exposes a REST API for
provisioning servers.

Throughout the documentation, Ironic Python Agent will be
abbreviated to IPA.

Index
=====

.. toctree::
    how_it_works
    rescue
    troubleshooting

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
